@@ -36,7 +36,7 @@ while(!feof(f))
 
 	for(i=len-2;i>=0;i--)
 		{
-		if(isspace(buf[i]))
+		if(isspace((int)(unsigned char)buf[i]))
 			{
 			buf[i] = 0;
 			continue;
@@ -47,7 +47,7 @@ while(!feof(f))
 	srt = NULL;
 	for(i=0;i<len;i++)
 		{
-		if(buf[i] && !isspace(buf[i]))
+		if(buf[i] && !isspace((int)(unsigned char)buf[i]))
 			{
 			srt = buf+i;
 			break;
@@ -183,8 +183,11 @@ for(i=0;i<argc;i++)
 }
 
 /*
- * $Id: args.c,v 1.2 2008/11/08 15:39:11 gtkwave Exp $
+ * $Id: args.c,v 1.3 2010/10/02 18:58:55 gtkwave Exp $
  * $Log: args.c,v $
+ * Revision 1.3  2010/10/02 18:58:55  gtkwave
+ * ctype.h compiler warning fixes (char vs int)
+ *
  * Revision 1.2  2008/11/08 15:39:11  gtkwave
  * updated -f argument file handling in vermin
  *
