@@ -243,7 +243,7 @@ if(ascii[len-1]=='}')
 
 	for(i=len-2;i>=2;i--)
 		{	
-		if(isdigit(ascii[i])) continue;
+		if(isdigit((int)(unsigned char)ascii[i])) continue;
 		if(ascii[i]=='{')
 			{
 			char *tsc = wave_alloca(i+1);
@@ -273,8 +273,11 @@ if(rc) return(*rc); else return(NULL);
 }
 
 /*
- * $Id: bsearch.c,v 1.9 2010/04/01 19:52:20 gtkwave Exp $
+ * $Id: bsearch.c,v 1.10 2010/10/02 18:58:55 gtkwave Exp $
  * $Log: bsearch.c,v $
+ * Revision 1.10  2010/10/02 18:58:55  gtkwave
+ * ctype.h compiler warning fixes (char vs int)
+ *
  * Revision 1.9  2010/04/01 19:52:20  gtkwave
  * time warp fixes
  *
