@@ -468,6 +468,8 @@ NULL, /* dual_ctx 196 */
 0, /* dual_id 197 */
 0, /* dual_attach_id_main_c_1 198 */
 0, /* dual_race_lock 199 */
+NULL, /* rpc_ctx */
+0, /* rpc_id */
 NULL, /* mainwindow 200 */
 NULL, /* signalwindow 201 */
 NULL, /* wavewindow 202 */
@@ -846,6 +848,12 @@ NULL, /* curnode 431 */
 NULL, /* previous_braced_tcl_string */
 
 
+/*
+ * tcl_helper.c
+ */
+0, /* in_tcl_callback */
+
+
 /*
  * timeentry.c
  */
@@ -908,6 +916,7 @@ NULL, /* treeopen_chain_curr */
 1, /* do_dynamic_treefilter */
 NULL, /* treesearch_gtk2_window_vbox */
 NULL, /* selected_hierarchy_name */
+NULL, /* selected_sig_name */
 NULL, /* gtk2_tree_frame */
 NULL, /* filter_entry */
 NULL, /* any_tree_node */
@@ -1140,6 +1149,7 @@ NULL, /* mvlfacs_vzt_c_3 587 */
 0, /* use_big_fonts 594 */
 0, /* use_nonprop_fonts */
 ~0, /* do_resize_signals 595 */
+0, /* initial_signal_window_width */
 0, /* constant_marker_update 596 */
 0, /* use_roundcaps 597 */
 ~0, /* show_base 598 */
@@ -1365,6 +1375,7 @@ void reload_into_new_context(void)
 	}
 
  printf("GTKWAVE | Reloading waveform...\n");
+ gtkwavetcl_setvar(WAVE_TCLCB_RELOAD_BEGIN, GLOBALS->loaded_file_name, WAVE_TCLCB_RELOAD_BEGIN_FLAGS); 
 
  /* Save state to file */
  save_tmpfilename = tmpnam_2(NULL, &fd_dummy);
@@ -1374,6 +1385,7 @@ void reload_into_new_context(void)
 #if !defined _MSC_VER && !defined __MINGW32__
    free_2(save_tmpfilename);
 #endif
+   gtkwavetcl_setvar_nonblocking(WAVE_TCLCB_ERROR,"reload failed",WAVE_TCLCB_ERROR_FLAGS);
    return;
  }
  if(fd_dummy >=0) close(fd_dummy);
@@ -1654,6 +1666,7 @@ void reload_into_new_context(void)
  new_globals->do_hier_compress = GLOBALS->do_hier_compress;
  new_globals->do_initial_zoom_fit = GLOBALS->do_initial_zoom_fit;
  new_globals->do_resize_signals = GLOBALS->do_resize_signals;
+ new_globals->initial_signal_window_width = GLOBALS->initial_signal_window_width;
  new_globals->enable_fast_exit = GLOBALS->enable_fast_exit;
  new_globals->enable_ghost_marker = GLOBALS->enable_ghost_marker;
  new_globals->enable_horiz_grid = GLOBALS->enable_horiz_grid;
@@ -1789,6 +1802,9 @@ void reload_into_new_context(void)
 #endif
  new_globals->dual_ctx = GLOBALS->dual_ctx;
   
+ new_globals->rpc_id = GLOBALS->rpc_id;
+ new_globals->rpc_ctx = GLOBALS->rpc_ctx;
+
  /* Times struct */
  memcpy(&(new_globals->tims), &(GLOBALS->tims), sizeof(Times));
 
@@ -2367,6 +2383,7 @@ void reload_into_new_context(void)
  GLOBALS->splash_disable = cached_splash_disable;
 
  printf("GTKWAVE | ...waveform reloaded\n");
+ gtkwavetcl_setvar(WAVE_TCLCB_RELOAD_END, GLOBALS->loaded_file_name, WAVE_TCLCB_RELOAD_END_FLAGS);
 }
 
 
@@ -2531,6 +2548,7 @@ switch(type)
 							GLOBALS->do_zoom_center = g_old->do_zoom_center;
 							GLOBALS->use_roundcaps = g_old->use_roundcaps;
 							GLOBALS->do_resize_signals = g_old->do_resize_signals;
+							GLOBALS->initial_signal_window_width = g_old->initial_signal_window_width;
 							GLOBALS->use_full_precision = g_old->use_full_precision;
 							GLOBALS->show_base = g_old->show_base;
 							GLOBALS->display_grid = g_old->display_grid;
@@ -2577,7 +2595,7 @@ struct Global *watch = *w;
 if(GLOBALS->gtk_context_bridge_ptr != w)
 	{
 #ifdef GTKWAVE_SIGNAL_CONNECT_DEBUG
-	printf("GTKWAVE | WARNING: globals change caught by ctx_swap_watchdog()! %p vs %p, session %d vs %d\n", 
+	fprintf(stderr, "GTKWAVE | WARNING: globals change caught by ctx_swap_watchdog()! %p vs %p, session %d vs %d\n", 
 		(void *)GLOBALS->gtk_context_bridge_ptr,(void *)w, (*GLOBALS->gtk_context_bridge_ptr)->this_context_page, watch->this_context_page);
 #endif
 
@@ -2634,12 +2652,19 @@ return(rc);
 
 void set_GLOBALS_x(struct Global *g, const char *file, int line)
 {
+char sstr[32];
+
 if(line)
 	{
 	printf("Globals old %p -> new %p (%s: %d)\n", (void *)GLOBALS, (void *)g, file, line);
 	}
 
-GLOBALS = g;
+if(GLOBALS != g)
+	{
+	GLOBALS = g;
+	sprintf(sstr, "%d", GLOBALS->this_context_page);
+	gtkwavetcl_setvar(WAVE_TCLCB_CURRENT_ACTIVE_TAB, sstr, WAVE_TCLCB_CURRENT_ACTIVE_TAB_FLAGS);
+	}
 }
 
 
