@@ -469,6 +469,8 @@ struct gtkwave_dual_ipc_t *dual_ctx; /* from main.c 207 */
 int dual_id; /* from main.c 208 */
 unsigned int dual_attach_id_main_c_1; /* from main.c 209 */
 int dual_race_lock; /* from main.c 210 */
+struct gtkwave_rpc_ipc_t *rpc_ctx; /* from main.c */
+unsigned int rpc_id; /* from main.c */
 GtkWidget *mainwindow; /* from main.c 211 */
 GtkWidget *signalwindow; /* from main.c 212 */
 GtkWidget *wavewindow; /* from main.c 213 */
@@ -830,6 +832,12 @@ int hashcache; /* from symbol.c 461 */
 char *previous_braced_tcl_string;
 
 
+/*
+ * tcl_helper.c
+ */
+char in_tcl_callback;
+
+
 /*
  * timeentry.c
  */
@@ -892,6 +900,7 @@ char tree_dnd_requested; /* from treesearch_gtk2.c */
 char do_dynamic_treefilter; /* from treesearch_gtk2.c */
 GtkWidget *treesearch_gtk2_window_vbox; /* from treesearch_gtk2.c */
 char *selected_hierarchy_name; /* from treesearch_gtk2.c */
+char *selected_sig_name; /* from treesearch_gtk2.c */
 GtkWidget *gtk2_tree_frame; /* from treesearch_gtk2.c */
 GtkWidget *filter_entry; /* from treesearch_gtk2.c */
 GtkCTreeNode *any_tree_node; /* from treesearch_gtk2.c */
@@ -1124,6 +1133,7 @@ char enable_vert_grid; /* from wavewindow.c 647 */
 char use_big_fonts; /* from wavewindow.c 648 */
 char use_nonprop_fonts; /* from wavewindow.c 649 */
 char do_resize_signals; /* from wavewindow.c 650 */
+int initial_signal_window_width;
 char constant_marker_update; /* from wavewindow.c 651 */
 char use_roundcaps; /* from wavewindow.c 652 */
 char show_base; /* from wavewindow.c 653 */
