@@ -77,13 +77,8 @@ typedef uint16_t 		lxtint16_t;
 typedef uint32_t		lxtint32_t;
 typedef uint64_t	 	lxtint64_t;
 #ifndef __MINGW32__
-#if __WORDSIZE == 64
-        #define LXT2_RD_LLD "%ld"
-        #define LXT2_RD_LD  "%d"
-#else
-        #define LXT2_RD_LLD "%lld"
-        #define LXT2_RD_LD "%ld"
-#endif
+#define LXT2_RD_LLD "%"PRId64   
+#define LXT2_RD_LD "%"PRId32
 #else
 #define LXT2_RD_LLD "%I64d"
 #define LXT2_RD_LD "%d"
@@ -299,8 +294,11 @@ unsigned int			lxt2_rd_unlimit_time_range(struct lxt2_rd_trace *lt);
 #endif
 
 /*
- * $Id: lxt2_read.h,v 1.4 2010/02/18 17:27:07 gtkwave Exp $
+ * $Id: lxt2_read.h,v 1.5 2010/05/27 06:49:31 gtkwave Exp $
  * $Log: lxt2_read.h,v $
+ * Revision 1.5  2010/05/27 06:49:31  gtkwave
+ * printf warnings fixes
+ *
  * Revision 1.4  2010/02/18 17:27:07  gtkwave
  * extern "C" headers / version bump
  *
