@@ -554,7 +554,7 @@ while(!feof(f))
 			for(;;)
 				{
 				if((*src == '\n') || (*src == '\r')) break;
-				if(isspace(*src))
+				if(isspace((int)(unsigned char)*src))
 					{
 					if(pchar != ' ') { *(pnt++) = pchar = ' '; }
 					src++;
@@ -771,8 +771,11 @@ return(0);
 }
 
 /*
- * $Id: vcd2fst.c,v 1.12 2010/07/16 16:12:38 gtkwave Exp $
+ * $Id: vcd2fst.c,v 1.13 2010/10/02 18:58:55 gtkwave Exp $
  * $Log: vcd2fst.c,v $
+ * Revision 1.13  2010/10/02 18:58:55  gtkwave
+ * ctype.h compiler warning fixes (char vs int)
+ *
  * Revision 1.12  2010/07/16 16:12:38  gtkwave
  * pedantic warning fixes
  *
