@@ -75,6 +75,7 @@
 #include <tk.h>
 #endif
 
+#include "rpc.h"
 
 static int suffix_check(const char *s, const char *sfx)
 {
@@ -103,6 +104,7 @@ GLOBALS->constant_marker_update = g_old->constant_marker_update;
 GLOBALS->do_zoom_center = g_old->do_zoom_center;
 GLOBALS->use_roundcaps = g_old->use_roundcaps;
 GLOBALS->do_resize_signals = g_old->do_resize_signals;
+GLOBALS->initial_signal_window_width = g_old->initial_signal_window_width;
 GLOBALS->scale_to_time_dimension = g_old->scale_to_time_dimension;
 GLOBALS->use_full_precision = g_old->use_full_precision;
 GLOBALS->show_base = g_old->show_base;
@@ -248,8 +250,10 @@ static void print_help(char *nam)
 
 #if !defined _MSC_VER && !defined __MINGW32__
 #define OUTPUT_GETOPT "  -O, --output=FILE          specify filename for stdout/stderr redirect\n"
+#define RPC_GETOPT "  -1, --rpcid=RPCID          specify RPCID of gtkwave_server to connect to\n"
 #else
 #define OUTPUT_GETOPT
+#define RPC_GETOPT
 #endif
 
 printf(
@@ -274,6 +278,7 @@ WAVE_GETOPT_CPUS
 "  -S, --script=FILE          specify Tcl command script file for execution\n"
 REPSCRIPT_GETOPT
 XID_GETOPT
+RPC_GETOPT
 INTR_GETOPT
 "  -C, --comphier             use compressed hierarchy names (slower)\n"
 "  -g, --giga                 use gigabyte mempacking when recoding (slower)\n"
@@ -516,6 +521,7 @@ if(!GLOBALS)
 	GLOBALS->disable_tooltips = old_g->disable_tooltips;
 	GLOBALS->do_initial_zoom_fit = old_g->do_initial_zoom_fit;
 	GLOBALS->do_resize_signals = old_g->do_resize_signals;
+	GLOBALS->initial_signal_window_width = old_g->initial_signal_window_width;
 	GLOBALS->scale_to_time_dimension = old_g->scale_to_time_dimension;
 	GLOBALS->enable_fast_exit = old_g->enable_fast_exit;
 	GLOBALS->enable_ghost_marker = old_g->enable_ghost_marker;
@@ -665,10 +671,11 @@ while (1)
                 {"repscript", 1, 0, 'R'},   
                 {"repperiod", 1, 0, 'P'},
 		{"output", 1, 0, 'O' },
+		{"rpc", 1, 0, '1' },
                 {0, 0, 0, 0}
                 };
 
-        c = getopt_long (argc, argv, "f:Fon:a:Ar:di:l:s:e:c:t:NS:vVhxX:MD:IgCLR:P:O:WT:", long_options, 
+        c = getopt_long (argc, argv, "f:Fon:a:Ar:di:l:s:e:c:t:NS:vVhxX:MD:IgCLR:P:O:WT:1:", long_options, 
 &option_index);
 
         if (c == -1) break;     /* no more args */
@@ -779,6 +786,10 @@ while (1)
                         break;
 #endif
 
+		case '1':
+			sscanf(optarg, "%x", &GLOBALS->rpc_id);
+			break;
+
 		case 'M':
 			GLOBALS->disable_menus = 1;
 			break;
@@ -839,6 +850,8 @@ while (1)
 			if(GLOBALS->stems_name) free_2(GLOBALS->stems_name);
 			GLOBALS->stems_name = malloc_2(strlen(optarg)+1);
 			strcpy(GLOBALS->stems_name, optarg);
+#else
+			fprintf(stderr, "GTKWAVE | Warning: '%c' option does not exist in this executable\n", c);
 #endif
 			break;
 
@@ -847,6 +860,8 @@ while (1)
 			GLOBALS->num_cpus = atoi(optarg);
 			if(GLOBALS->num_cpus<1) GLOBALS->num_cpus = 1;
 			if(GLOBALS->num_cpus>8) GLOBALS->num_cpus = 8;
+#else
+			fprintf(stderr, "GTKWAVE | Warning: '%c' option does not exist in this executable\n", c);
 #endif
                         break;
 
@@ -907,6 +922,7 @@ while (1)
 
                 case 'T':
 #if defined(WIN32) && defined(USE_TCL_STUBS)
+			fprintf(stderr, "GTKWAVE | Warning: '%c' option does not exist in this executable\n", c);
 #else
 		        {
 			  char* pos;
@@ -1899,11 +1915,31 @@ GLOBALS->signalwindow = create_signalwindow();
 if(GLOBALS->do_resize_signals) 
                 {
                 int os;
-                os=GLOBALS->max_signal_name_pixel_width;
+
+		if(GLOBALS->initial_signal_window_width > GLOBALS->max_signal_name_pixel_width)
+			{
+			os=GLOBALS->initial_signal_window_width;
+			}
+			else
+			{
+	                os=GLOBALS->max_signal_name_pixel_width;
+			}
+
                 os=(os<48)?48:os;
                 gtk_widget_set_usize(GTK_WIDGET(GLOBALS->signalwindow),
                                 os+30, -1);
                 }
+else
+	{
+	if(GLOBALS->initial_signal_window_width)
+		{
+		int os;
+
+		os=GLOBALS->initial_signal_window_width;
+		os=(os<48)?48:os;
+		gtk_widget_set_usize(GTK_WIDGET(GLOBALS->signalwindow), os+30, -1);
+		}
+	}
 
 gtk_widget_show(GLOBALS->signalwindow);
 
@@ -2099,6 +2135,27 @@ if(scriptfile)
 	scriptfile=NULL;
 	}
 
+#if !defined(_MSC_VER) && !defined(__MINGW32__)
+if(GLOBALS->rpc_id)
+	{
+	GLOBALS->rpc_ctx = shmat(GLOBALS->rpc_id, NULL, 0);
+	if(GLOBALS->rpc_ctx)
+		{
+                if(memcmp(&GLOBALS->rpc_ctx->matchword, RPC_MATCHWORD, 4))
+                        {
+                        fprintf(stderr, "RPC shared memory ID matchword mismatch, exiting.\n");
+                        exit(255);
+                        }
+		}
+		else
+		{
+                fprintf(stderr, "Not a valid RPC shared memory ID for remote operation, exiting.\n");
+                exit(255);
+		}
+	}
+
+#endif
+
 #if !defined _MSC_VER
 if(GLOBALS->dual_attach_id_main_c_1)
 	{
@@ -2654,8 +2711,17 @@ void optimize_vcd_file(void) {
 #endif
 
 /*
- * $Id: main.c,v 1.99 2010/07/12 20:51:42 gtkwave Exp $
+ * $Id: main.c,v 1.102 2010/10/26 17:37:35 gtkwave Exp $
  * $Log: main.c,v $
+ * Revision 1.102  2010/10/26 17:37:35  gtkwave
+ * added initial_signal_window_width rc variable
+ *
+ * Revision 1.101  2010/10/06 20:15:51  gtkwave
+ * preliminary version of RPC mechanism
+ *
+ * Revision 1.100  2010/09/14 17:11:56  gtkwave
+ * added warning for unimplemented flags (for some systems)
+ *
  * Revision 1.99  2010/07/12 20:51:42  gtkwave
  * free to non-malloc'd address fix
  *
