@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) Tony Bybell 1999-2009.
+ * Copyright (c) Tony Bybell 1999-2010.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -15,6 +15,7 @@
 #include "pixmaps.h"
 #include "symbol.h"
 #include "debug.h"
+#include "rpc.h"
 
 #undef FOCUS_DEBUG_MSGS
 
@@ -619,6 +620,8 @@ GdkEventMotion event[1];
 event[0].deviceid = GDK_CORE_POINTER;  
 #endif
 
+execute_rpc();
+
 if(GLOBALS->loaded_file_type == MISSING_FILE)
 	{
 	return(TRUE);
@@ -1389,8 +1392,11 @@ gtk_signal_disconnect(GTK_OBJECT(GLOBALS->mainwindow), id);
 
 
 /*
- * $Id: signalwindow.c,v 1.50 2010/04/14 07:49:02 gtkwave Exp $
+ * $Id: signalwindow.c,v 1.51 2010/10/06 20:15:51 gtkwave Exp $
  * $Log: signalwindow.c,v $
+ * Revision 1.51  2010/10/06 20:15:51  gtkwave
+ * preliminary version of RPC mechanism
+ *
  * Revision 1.50  2010/04/14 07:49:02  gtkwave
  * updated mouseover handling
  *
