@@ -1566,34 +1566,36 @@ int SST_open_node(char *name) ;
 static int gtkwavetcl_forceOpenTreeNode(ClientData clientData, Tcl_Interp *interp, int objc, Tcl_Obj *CONST objv[])
 {
   int rv = -100;		/* Tree does not exist */
-if(objc == 2)
-        {
-        char *s = get_Tcl_string(objv[1]);
-
-	if(s)
-		{
-		int len = strlen(s);
-		if(s[len-1]!=GLOBALS->hier_delimeter)
-			{
+  char *s = NULL ;
+  if(objc == 2)
+    s = get_Tcl_string(objv[1]);
+  
+  if(s && (strlen(s) > 1)) {	/* exclude empty strings */
+    int len = strlen(s);
+    if(s[len-1]!=GLOBALS->hier_delimeter)
+      {
 #ifdef WAVE_USE_GTK2
-			rv = SST_open_node(s);
+	rv = SST_open_node(s);
 #endif
-			}
-			else
-			{
+      }
+    else {
 #ifdef WAVE_USE_GTK2
-
-			rv = SST_open_node(s);
+      rv = SST_open_node(s);
 #endif
-	    }
-	}
-      gtkwave_main_iteration(); /* check if this is needed */
     }
-  else  
-    {
-      return(gtkwavetcl_badNumArgs(clientData, interp, objc, objv, 1));
+  } else {
+    if (GLOBALS->selected_hierarchy_name) {
+      rv = SST_NODE_CURRENT ;
     }
-  Tcl_SetObjResult(GLOBALS->interp, Tcl_NewIntObj(rv)) ;
+    gtkwave_main_iteration(); /* check if this is needed */
+  }
+  if (rv == -100) {
+    return(gtkwavetcl_badNumArgs(clientData, interp, objc, objv, 1));
+  }
+  Tcl_SetObjResult(GLOBALS->interp, (rv == SST_NODE_CURRENT) ?
+		   Tcl_NewStringObj(GLOBALS->selected_hierarchy_name,
+				    strlen(GLOBALS->selected_hierarchy_name)) :
+		   Tcl_NewIntObj(rv)) ;
   
   return(TCL_OK);
 }
@@ -1726,12 +1728,17 @@ static int gtkwavetcl_loadFile(ClientData clientData, Tcl_Interp *interp, int ob
     {
       char *s = get_Tcl_string(objv[1]);
 	
-      /*	read_save_helper(s); */
-      process_url_file(s);
-      /*	process_url_list(s); */
-      /*	gtkwave_main_iteration(); */
-
-
+      if(!GLOBALS->in_tcl_callback)                          
+        {
+        /*	read_save_helper(s); */
+        process_url_file(s);
+        /*	process_url_list(s); */
+        /*	gtkwave_main_iteration(); */
+        }
+	else
+	{
+	gtkwavetcl_setvar_nonblocking(WAVE_TCLCB_ERROR,"gtkwave::loadFile prohibited in callback",WAVE_TCLCB_ERROR_FLAGS);
+	}
     }
   else  
     {
@@ -1746,7 +1753,14 @@ static int gtkwavetcl_reLoadFile(ClientData clientData, Tcl_Interp *interp, int
 
   if(objc == 1)
     {
-      reload_into_new_context();
+      if(!GLOBALS->in_tcl_callback)
+	{
+      	reload_into_new_context();
+	}
+	else
+	{
+	gtkwavetcl_setvar_nonblocking(WAVE_TCLCB_ERROR,"gtkwave::reLoadFile prohibited in callback",WAVE_TCLCB_ERROR_FLAGS);
+	}
     }
   else  
     {
@@ -1821,6 +1835,7 @@ if(i < GLOBALS->num_notebook_pages)
         GLOBALS->do_zoom_center = g_old->do_zoom_center;
         GLOBALS->use_roundcaps = g_old->use_roundcaps;
         GLOBALS->do_resize_signals = g_old->do_resize_signals;
+	GLOBALS->initial_signal_window_width = g_old->initial_signal_window_width;
         GLOBALS->use_full_precision = g_old->use_full_precision;
         GLOBALS->show_base = g_old->show_base;
         GLOBALS->display_grid = g_old->display_grid;
@@ -1843,14 +1858,25 @@ static int gtkwavetcl_setTabActive(ClientData clientData, Tcl_Interp *interp, in
 {
 if(objc == 2)
         {       
-        char *s = get_Tcl_string(objv[1]);
-        unsigned int tabnum = atoi(s);
-	gint rc = switch_to_tab_number(tabnum);
+	gint rc;
+
+	if(!GLOBALS->in_tcl_callback)
+		{
+        	char *s = get_Tcl_string(objv[1]);
+        	unsigned int tabnum = atoi(s);
+		rc = switch_to_tab_number(tabnum);
         
-        MaxSignalLength();
-        signalarea_configure_event(GLOBALS->signalarea, NULL);
+        	MaxSignalLength();
+        	signalarea_configure_event(GLOBALS->signalarea, NULL);
         
-        gtkwave_main_iteration();
+        	gtkwave_main_iteration();
+		}
+		else
+		{
+		gtkwavetcl_setvar_nonblocking(WAVE_TCLCB_ERROR,"gtkwave::setTabActive prohibited in callback",WAVE_TCLCB_ERROR_FLAGS);
+		rc = -1;
+		}
+
 	return(gtkwavetcl_printInteger(clientData, interp, objc, objv, rc));
         }
         else
@@ -1868,6 +1894,131 @@ return(gtkwavetcl_printInteger(clientData, interp, objc, objv, value));
 }
 
 
+static int gtkwavetcl_installFileFilter(ClientData clientData, Tcl_Interp *interp, int objc, Tcl_Obj *CONST objv[])
+{
+if(objc == 2)
+        {       
+        char *s = get_Tcl_string(objv[1]);
+        unsigned int which = atoi(s);
+	gint rc = install_file_filter(which);
+        
+        gtkwave_main_iteration();
+	return(gtkwavetcl_printInteger(clientData, interp, objc, objv, rc));
+        }
+        else
+        {
+        return(gtkwavetcl_badNumArgs(clientData, interp, objc, objv, 1));
+        }
+       
+}
+
+
+static int gtkwavetcl_setCurrentTranslateFile(ClientData clientData, Tcl_Interp *interp, int objc, Tcl_Obj *CONST objv[])
+{
+if(objc == 2)
+        {       
+        char *s = get_Tcl_string(objv[1]);
+	set_current_translate_file(s);
+
+	return(gtkwavetcl_printInteger(clientData, interp, objc, objv, GLOBALS->current_translate_file));
+        }
+        else
+        {
+        return(gtkwavetcl_badNumArgs(clientData, interp, objc, objv, 1));
+        }
+       
+}
+
+
+static int gtkwavetcl_setCurrentTranslateEnums(ClientData clientData, Tcl_Interp *interp, int objc, Tcl_Obj *CONST objv[])
+{
+if(objc == 2)
+        {       
+        char *s = get_Tcl_string(objv[1]);
+	set_current_translate_enums(s);
+
+	return(gtkwavetcl_printInteger(clientData, interp, objc, objv, GLOBALS->current_translate_file));
+        }
+        else
+        {
+        return(gtkwavetcl_badNumArgs(clientData, interp, objc, objv, 1));
+        }
+       
+}
+
+
+static int gtkwavetcl_installProcFilter(ClientData clientData, Tcl_Interp *interp, int objc, Tcl_Obj *CONST objv[])
+{
+if(objc == 2)
+        {       
+        char *s = get_Tcl_string(objv[1]);
+        unsigned int which = atoi(s);
+	gint rc = install_file_filter(which);
+        
+        gtkwave_main_iteration();
+	return(gtkwavetcl_printInteger(clientData, interp, objc, objv, rc));
+        }
+        else
+        {
+        return(gtkwavetcl_badNumArgs(clientData, interp, objc, objv, 1));
+        }
+       
+}
+
+
+static int gtkwavetcl_setCurrentTranslateProc(ClientData clientData, Tcl_Interp *interp, int objc, Tcl_Obj *CONST objv[])
+{
+if(objc == 2)
+        {       
+        char *s = get_Tcl_string(objv[1]);
+	set_current_translate_proc(s);
+
+	return(gtkwavetcl_printInteger(clientData, interp, objc, objv, GLOBALS->current_translate_proc));
+        }
+        else
+        {
+        return(gtkwavetcl_badNumArgs(clientData, interp, objc, objv, 1));
+        }
+       
+}
+
+
+static int gtkwavetcl_installTransFilter(ClientData clientData, Tcl_Interp *interp, int objc, Tcl_Obj *CONST objv[])
+{
+if(objc == 2)
+        {       
+        char *s = get_Tcl_string(objv[1]);
+        unsigned int which = atoi(s);
+	gint rc = install_ttrans_filter(which);
+        
+        gtkwave_main_iteration();
+	return(gtkwavetcl_printInteger(clientData, interp, objc, objv, rc));
+        }
+        else
+        {
+        return(gtkwavetcl_badNumArgs(clientData, interp, objc, objv, 1));
+        }
+       
+}
+
+
+static int gtkwavetcl_setCurrentTranslateTransProc(ClientData clientData, Tcl_Interp *interp, int objc, Tcl_Obj *CONST objv[])
+{
+if(objc == 2)
+        {       
+        char *s = get_Tcl_string(objv[1]);
+	set_current_translate_ttrans(s);
+
+	return(gtkwavetcl_printInteger(clientData, interp, objc, objv, GLOBALS->current_translate_ttrans));
+        }
+        else
+        {
+        return(gtkwavetcl_badNumArgs(clientData, interp, objc, objv, 1));
+        }
+       
+}
+
+
 tcl_cmdstruct gtkwave_commands[] =
 	{
 	{"addSignalsFromList",			gtkwavetcl_addSignalsFromList},
@@ -1914,8 +2065,15 @@ tcl_cmdstruct gtkwave_commands[] =
 	{"getWindowStartTime", 			gtkwavetcl_getWindowStartTime},
 	{"getZoomFactor",			gtkwavetcl_getZoomFactor},
 	{"highlightSignalsFromList",		gtkwavetcl_highlightSignalsFromList},
+	{"installFileFilter",			gtkwavetcl_installFileFilter},
+	{"installProcFilter",			gtkwavetcl_installProcFilter},
+	{"installTransFilter",			gtkwavetcl_installTransFilter},
    	{"nop", 				gtkwavetcl_nop},
 	{"setBaselineMarker",			gtkwavetcl_setBaselineMarker},
+	{"setCurrentTranslateEnums",		gtkwavetcl_setCurrentTranslateEnums},
+	{"setCurrentTranslateFile",		gtkwavetcl_setCurrentTranslateFile},
+	{"setCurrentTranslateProc",		gtkwavetcl_setCurrentTranslateProc},
+	{"setCurrentTranslateTransProc",	gtkwavetcl_setCurrentTranslateTransProc},
 	{"setFromEntry",			gtkwavetcl_setFromEntry},
 	{"setLeftJustifySigs",			gtkwavetcl_setLeftJustifySigs},
 	{"setMarker",				gtkwavetcl_setMarker},
@@ -1948,8 +2106,26 @@ static void dummy_function(void)
 
 
 /*
- * $Id: tcl_commands.c,v 1.39 2010/05/21 19:47:58 gtkwave Exp $
+ * $Id: tcl_commands.c,v 1.45 2010/10/26 17:37:35 gtkwave Exp $
  * $Log: tcl_commands.c,v $
+ * Revision 1.45  2010/10/26 17:37:35  gtkwave
+ * added initial_signal_window_width rc variable
+ *
+ * Revision 1.44  2010/08/17 01:51:35  gtkwave
+ * added missing global in error message
+ *
+ * Revision 1.43  2010/08/15 18:54:49  gtkwave
+ * fixes to SST open node to support tcl bug workaround (?)
+ *
+ * Revision 1.42  2010/07/28 19:56:27  gtkwave
+ * locking down callbacks from calling context changing events in viewer
+ *
+ * Revision 1.41  2010/07/19 22:32:31  gtkwave
+ * added gtkwave::setCurrentTranslateEnums
+ *
+ * Revision 1.40  2010/07/19 21:12:19  gtkwave
+ * added file/proc/trans access functions to Tcl script interpreter
+ *
  * Revision 1.39  2010/05/21 19:47:58  gtkwave
  * fixes to tcl string handling on { ... } string case.
  *
