@@ -62,14 +62,6 @@ for(j=0;j<GLOBALS->num_notebook_pages;j++)
 	}
 }
 
-#if defined __MINGW32__ || defined _MSC_VER
-
-void ttrans_searchbox(char *title) { }
-void install_ttrans_filter(int which) { } 
-void set_current_translate_ttrans(char *name) { }
-int traverse_vector_nodes(Trptr t) { if(t) { t->t_filter = 0; } return(0); }
-
-#else
 
 int traverse_vector_nodes(Trptr t);
 
@@ -124,7 +116,7 @@ static void load_ttrans_filter(int which, char *name)
   arg = name + strlen(exec_name);
 
   /* remove leading spaces from argument */
-  while (isspace(arg[0])) {
+  while (isspace((int)(unsigned char)arg[0])) {
     arg++;
   }
 
@@ -140,6 +132,7 @@ static void load_ttrans_filter(int which, char *name)
   }
 
   /* turn the exec_name into an absolute path */
+#if !defined __MINGW32__ && !defined _MSC_VER
   cmd = (char *)malloc_2(strlen(exec_name)+6+1);
   sprintf(cmd, "which %s", exec_name);
   stream = popen(cmd, "r");
@@ -155,6 +148,9 @@ static void load_ttrans_filter(int which, char *name)
 
   pclose(stream);
   free_2(cmd);
+#else
+  strcpy(abs_path, exec_name);
+#endif
 
   /* remove_ttrans_filter(which, 0); ... should never happen from GUI, but perhaps possible from save files or other weirdness */
   if(!GLOBALS->ttrans_filter[which])
@@ -163,10 +159,15 @@ static void load_ttrans_filter(int which, char *name)
 	}
 }
 
-void install_ttrans_filter(int which)
+int install_ttrans_filter(int which)
 {
 int found = 0;
 
+if((which<0)||(which>=(PROC_FILTER_MAX+1)))
+        {
+        which = 0;
+        }
+
 if(GLOBALS->traces.first)  
         {
         Trptr t = GLOBALS->traces.first;
@@ -231,7 +232,7 @@ if(GLOBALS->traces.first)
 					t->flags |= TR_TTRANSLATED;
 					traverse_vector_nodes(t);
 					}
-                                found = 1;
+                                found++;
 
 				if(t->t_match)
 					{
@@ -252,6 +253,8 @@ if(found)
 	{
 	regen_display();
 	}
+
+return(found);
 }
 
 /************************************************************************/
@@ -514,7 +517,11 @@ int cvt_ok = 0;
 
 if((t->t_filter) && (t->flags & TR_TTRANSLATED) && (t->vector) && (!t->t_filter_converted))
 	{
+#if !defined _MSC_VER && !defined __MINGW32__
 	int rc = save_nodes_to_trans(GLOBALS->ttrans_filter[t->t_filter]->sout, t);
+#else
+	int rc = save_nodes_to_trans((FILE *)(GLOBALS->ttrans_filter[t->t_filter]->g_hChildStd_IN_Wr), t);
+#endif
 
 	if(rc == VCDSAV_OK)
 		{
@@ -546,6 +553,7 @@ if((t->t_filter) && (t->flags & TR_TTRANSLATED) && (t->vector) && (!t->t_filter_
 				char buf[1025];
 				char *pnt, *rtn;
 	
+#if !defined _MSC_VER && !defined __MINGW32__
 				if(feof(GLOBALS->ttrans_filter[t->t_filter]->sin)) break; /* should never happen */
 	
 				buf[0] = 0;
@@ -557,8 +565,30 @@ if((t->t_filter) && (t->flags & TR_TTRANSLATED) && (t->vector) && (!t->t_filter_
 					if((*rtn == '\n') || (*rtn == '\r')) { *rtn = 0; break; }
 					rtn++;
 					}
+#else
+			        {
+			        BOOL bSuccess;
+			        DWORD dwRead;
+				int n;
+
+			        for(n=0;n<1024;n++)
+			                {
+			                do      {
+			                        bSuccess = ReadFile(GLOBALS->ttrans_filter[t->t_filter]->g_hChildStd_OUT_Rd, buf+n, 1, &dwRead, NULL);
+			                        if((!bSuccess)||(buf[n]=='\n'))
+			                                {
+			                                goto ex;
+			                                }
+			
+			                        } while(buf[n]=='\r');
+			                }
+ex:     			buf[n] = 0;
+				pnt = buf;
+			        }
+#endif
+
 	
-				while(*pnt) { if(isspace(*pnt)) pnt++; else break;}
+				while(*pnt) { if(isspace((int)(unsigned char)*pnt)) pnt++; else break;}
 	
 				if(*pnt=='#')
 					{
@@ -566,8 +596,8 @@ if((t->t_filter) && (t->flags & TR_TTRANSLATED) && (t->vector) && (!t->t_filter_
 					int slen;
 					char *sp;
 	
-					while(*pnt) { if(!isspace(*pnt)) pnt++; else break; }
-					while(*pnt) { if(isspace(*pnt)) pnt++; else break; }
+					while(*pnt) { if(!isspace((int)(unsigned char)*pnt)) pnt++; else break; }
+					while(*pnt) { if(isspace((int)(unsigned char)*pnt)) pnt++; else break; }
 	
 					sp = pnt;
 					slen = strlen(sp);
@@ -577,7 +607,7 @@ if((t->t_filter) && (t->flags & TR_TTRANSLATED) && (t->vector) && (!t->t_filter_
 						pnt = sp + slen - 1;
 						do
 							{
-							if(isspace(*pnt)) { *pnt = 0; pnt--; slen--; } else { break; }
+							if(isspace((int)(unsigned char)*pnt)) { *pnt = 0; pnt--; slen--; } else { break; }
 							} while(pnt != (sp-1));
 						}
 						
@@ -619,8 +649,8 @@ if((t->t_filter) && (t->flags & TR_TTRANSLATED) && (t->vector) && (!t->t_filter_
 						if(tim < LLDescriptor(0)) tim = LLDescriptor(-1);
 						GLOBALS->named_markers[which_marker] = tim;
 	
-						while(*pnt) { if(!isspace(*pnt)) pnt++; else break; }
-						while(*pnt) { if(isspace(*pnt)) pnt++; else break; }
+						while(*pnt) { if(!isspace((int)(unsigned char)*pnt)) pnt++; else break; }
+						while(*pnt) { if(isspace((int)(unsigned char)*pnt)) pnt++; else break; }
 		
 						sp = pnt;
 						slen = strlen(sp);
@@ -630,7 +660,7 @@ if((t->t_filter) && (t->flags & TR_TTRANSLATED) && (t->vector) && (!t->t_filter_
 							pnt = sp + slen - 1;
 							do
 								{
-								if(isspace(*pnt)) { *pnt = 0; pnt--; slen--; } else { break; }
+								if(isspace((int)(unsigned char)*pnt)) { *pnt = 0; pnt--; slen--; } else { break; }
 								} while(pnt != (sp-1));
 							}
 	
@@ -659,7 +689,7 @@ if((t->t_filter) && (t->flags & TR_TTRANSLATED) && (t->vector) && (!t->t_filter_
 						char *sp;
 	
 						pnt+=5;
-						while(*pnt) { if(isspace(*pnt)) pnt++; else break; }
+						while(*pnt) { if(isspace((int)(unsigned char)*pnt)) pnt++; else break; }
 		
 						sp = pnt;
 						slen = strlen(sp);
@@ -669,7 +699,7 @@ if((t->t_filter) && (t->flags & TR_TTRANSLATED) && (t->vector) && (!t->t_filter_
 							pnt = sp + slen - 1;
 							do
 								{
-								if(isspace(*pnt)) { *pnt = 0; pnt--; slen--; } else { break; }
+								if(isspace((int)(unsigned char)*pnt)) { *pnt = 0; pnt--; slen--; } else { break; }
 								} while(pnt != (sp-1));
 							}
 	
@@ -737,11 +767,18 @@ if((t->t_filter) && (t->flags & TR_TTRANSLATED) && (t->vector) && (!t->t_filter_
 return(cvt_ok);
 }
 
-#endif
-
 /*
- * $Id: ttranslate.c,v 1.18 2010/06/23 05:45:34 gtkwave Exp $
+ * $Id: ttranslate.c,v 1.21 2010/10/02 18:58:55 gtkwave Exp $
  * $Log: ttranslate.c,v $
+ * Revision 1.21  2010/10/02 18:58:55  gtkwave
+ * ctype.h compiler warning fixes (char vs int)
+ *
+ * Revision 1.20  2010/08/26 18:42:23  gtkwave
+ * added support for transaction filters in mingw
+ *
+ * Revision 1.19  2010/07/19 21:12:19  gtkwave
+ * added file/proc/trans access functions to Tcl script interpreter
+ *
  * Revision 1.18  2010/06/23 05:45:34  gtkwave
  * warnings fixes
  *
