@@ -2587,7 +2587,7 @@ if(GLOBALS->vcd_is_compressed_vcd_c_1)
 GLOBALS->min_time=GLOBALS->start_time_vcd_c_1*GLOBALS->time_scale;
 GLOBALS->max_time=GLOBALS->end_time_vcd_c_1*GLOBALS->time_scale;
 
-if((GLOBALS->min_time==GLOBALS->max_time)||(GLOBALS->max_time==0))
+if((GLOBALS->min_time==GLOBALS->max_time)&&(GLOBALS->max_time==LLDescriptor(-1)))
         {
         fprintf(stderr, "VCD times range is equal to zero.  Exiting.\n");
         vcd_exit(255);
@@ -2618,8 +2618,11 @@ return(GLOBALS->max_time);
 /*******************************************************************************/
 
 /*
- * $Id: vcd.c,v 1.34 2010/06/02 03:51:30 gtkwave Exp $
+ * $Id: vcd.c,v 1.35 2010/09/29 00:24:41 gtkwave Exp $
  * $Log: vcd.c,v $
+ * Revision 1.35  2010/09/29 00:24:41  gtkwave
+ * allow range = 0 in VCD files for min and max times
+ *
  * Revision 1.34  2010/06/02 03:51:30  gtkwave
  * don't autocoalesce escape identifiers
  *
