@@ -2688,8 +2688,8 @@ if (((flen>2)&&(!strcmp(fname+flen-3,".gz")))||
 			if(!GLOBALS->vlist_prepack)
 				{
 				fprintf(stderr, "Warning! File size is %d MB.  This might fail in recoding.\n"
-					"Consider converting it to lxt, lxt2, or vzt database formats instead.  (See\n"
-					"the vcd2lxt(1), vcd2lxt2(1), and vzt2vzt(1) manpages for more information.)\n"
+					"Consider converting it to the fst database format instead.  (See the\n"
+					"vcd2fst(1) manpage for more information.)\n"
 					"To disable this warning, set rc variable vcd_warning_filesize to zero.\n"
 					"Alternatively, use the -o, --optimize command line option to convert to LXT2\n"
 					"or the -g, --giga command line option to use dynamically compressed memory.\n\n",
@@ -2797,7 +2797,7 @@ if(GLOBALS->vcd_is_compressed_vcd_recoder_c_2)
 GLOBALS->min_time=GLOBALS->start_time_vcd_recoder_c_3*GLOBALS->time_scale;
 GLOBALS->max_time=GLOBALS->end_time_vcd_recoder_c_3*GLOBALS->time_scale;
 
-if((GLOBALS->min_time==GLOBALS->max_time)||(GLOBALS->max_time==0))
+if((GLOBALS->min_time==GLOBALS->max_time)&&(GLOBALS->max_time==LLDescriptor(-1)))
         {
         fprintf(stderr, "VCD times range is equal to zero.  Exiting.\n");
         vcd_exit(255);
@@ -3234,8 +3234,14 @@ np->mv.mvlfac_vlist = NULL;
 }
 
 /*
- * $Id: vcd_recoder.c,v 1.43 2010/06/02 03:51:30 gtkwave Exp $
+ * $Id: vcd_recoder.c,v 1.45 2010/09/29 00:24:41 gtkwave Exp $
  * $Log: vcd_recoder.c,v $
+ * Revision 1.45  2010/09/29 00:24:41  gtkwave
+ * allow range = 0 in VCD files for min and max times
+ *
+ * Revision 1.44  2010/09/24 15:44:41  gtkwave
+ * changed large file size message to redirect to fst usage
+ *
  * Revision 1.43  2010/06/02 03:51:30  gtkwave
  * don't autocoalesce escape identifiers
  *
